==> haskell-statevar-1.1.0.4-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-statevar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: StateVar
version: 1.1.0.4
id: StateVar-1.1.0.4-GRmz1UWBbi54rweYG8Cc71
key: StateVar-1.1.0.4-GRmz1UWBbi54rweYG8Cc71
license: BSD3
copyright: Copyright (C) 2014-2015 Edward A. Kmett, 2009-2016 Sven Panne
maintainer: Sven Panne <svenpanne@gmail.com>
homepage: https://github.com/haskell-opengl/StateVar
synopsis: State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.
category: Data
author: Sven Panne and Edward Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.StateVar
abi: f6e1a31d522f4d232cfc1e975ba0c85c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/StateVar-1.1.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/StateVar-1.1.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/StateVar-1.1.0.4
hs-libraries: HSStateVar-1.1.0.4-GRmz1UWBbi54rweYG8Cc71
depends:
    base-4.10.1.0 stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html: /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statevar-1.1.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-statevar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: StateVar
version: 1.1.1.0
id: StateVar-1.1.1.0-6SqVHjIDY01BSHlFA5jy8D
key: StateVar-1.1.1.0-6SqVHjIDY01BSHlFA5jy8D
license: BSD3
copyright: Copyright (C) 2014-2015 Edward A. Kmett, 2009-2018 Sven Panne
maintainer: Sven Panne <svenpanne@gmail.com>
homepage: https://github.com/haskell-opengl/StateVar
synopsis: State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.
category: Data
author: Sven Panne and Edward Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.StateVar
abi: 87fc9148d11f83b0849d8469f5947758
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/StateVar-1.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/StateVar-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/StateVar-1.1.1.0
hs-libraries: HSStateVar-1.1.1.0-6SqVHjIDY01BSHlFA5jy8D
depends:
    base-4.10.1.0 stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html: /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
